Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3629)

Unified Diff: chrome/browser/sync/test/integration/apps_helper.h

Issue 11308072: Include v2 packaged apps in sync. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: make the tests actually pass Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/apps_helper.h
diff --git a/chrome/browser/sync/test/integration/apps_helper.h b/chrome/browser/sync/test/integration/apps_helper.h
index bd6a9688ddf4f38bf2a5f40792e45f756fde664c..f2a4dbbc4be7caa061e106564a6246c40b13916f 100644
--- a/chrome/browser/sync/test/integration/apps_helper.h
+++ b/chrome/browser/sync/test/integration/apps_helper.h
@@ -14,17 +14,22 @@ class Profile;
namespace apps_helper {
// Returns true iff the profile with index |index| has the same apps as the
// verifier.
bool HasSameAppsAsVerifier(int index) WARN_UNUSED_RESULT;
// Returns true iff all existing profiles have the same apps as the verifier.
bool AllProfilesHaveSameAppsAsVerifier() WARN_UNUSED_RESULT;
// Installs the app for the given index to |profile|, and returns the extension
// ID of the new app.
std::string InstallApp(Profile* profile, int index);
+// Installs the platform app for the given index to |profile|, and returns the
+// extension ID of the new app.
akalin 2012/11/19 19:28:59 perhaps add a comment about how one shouldn't inst
Marijn Kruisselbrink 2012/11/19 19:39:59 Done.
+std::string InstallPlatformApp(Profile* profile, int index);
+
// Installs the app for the given index to all profiles (including the
// verifier), and returns the extension ID of the new app.
std::string InstallAppForAllProfiles(int index);
@@ -39,7 +44,7 @@ void InstallAppsPendingForSync(Profile* profile);
// Enables the app for the given index on |profile|.
void EnableApp(Profile* profile, int index);
// Disables the appfor the given index on |profile|.
void DisableApp(Profile* profile, int index);
// Enables the app for the given index in incognito mode on |profile|.
@@ -14,17 +14,22 @@ class Profile;
namespace apps_helper {
-// Returns true iff the profile with index |index| has the same apps as the
-// verifier.
+// Returns true iff the profile with index |index| has the same apps (hosted,
+// legacy packaged and platform) as the verifier.
bool HasSameAppsAsVerifier(int index) WARN_UNUSED_RESULT;
@@ -14,17 +14,22 @@ class Profile;
bool HasSameAppsAsVerifier(int index) WARN_UNUSED_RESULT;
-// Returns true iff all existing profiles have the same apps as the verifier.
+// Returns true iff all existing profiles have the same apps (hosted,
+// legacy packaged and platform) as the verifier.
bool AllProfilesHaveSameAppsAsVerifier() WARN_UNUSED_RESULT;
// Installs the app for the given index to |profile|, and returns the extension
@@ -39,7 +44,7 @@ void InstallAppsPendingForSync(Profile* profile);
// Enables the app for the given index on |profile|.
void EnableApp(Profile* profile, int index);
-// Disables the appfor the given index on |profile|.
+// Disables the app for the given index on |profile|.
void DisableApp(Profile* profile, int index);
// Enables the app for the given index in incognito mode on |profile|.

Powered by Google App Engine
This is Rietveld 408576698